@@ -227,7 +227,7 @@ class Window(QtWidgets.QMainWindow):
 
         layout = QtWidgets.QVBoxLayout(panels["body"])
         layout.setSpacing(0)
-        layout.setContentsMargins(0, 0, 0, 0)
+        layout.setContentsMargins(1, 0, 1, 0)
         layout.addWidget(widgets["apps"])
         layout.addWidget(widgets["fullCommand"])
 
@@ -455,10 +455,16 @@ class Window(QtWidgets.QMainWindow):
             allzparkconfig.exclude_filter = value
             self._ctrl.reset()
 
+        if key == "theme":
+            user_css = self._ctrl.state.retrieve("userCss", "")
+            self._originalcss = res.load_theme(value)
+            self.setStyleSheet("\n".join([self._originalcss,
+                                          res.format_stylesheet(user_css)]))
+
     def on_dock_toggled(self, dock, visible):
         """Make toggled dock the active dock"""
 
-        if not visible or dock == self._docks["profiles"]:
+        if not visible:
             return
 
         # Handle the easy cases first
@@ -467,11 +473,19 @@ class Window(QtWidgets.QMainWindow):
         allow_multiple = bool(self._ctrl.state.retrieve("allowMultipleDocks"))
 
         if ctrl_held or not allow_multiple:
+            ignore_allow_multiple = [
+                # docks that are not restricted by this rule
+                "profiles",
+            ]
+
             for name, d in self._docks.items():
-                if name == "profiles":
+                if name in ignore_allow_multiple:
                     continue
                 d.setVisible(d == dock)
-            return
+
+            if len([d for d in self._docks.values() if d.isVisible()]) <= 1:
+                # Only one or no visible dock
+                return
 
         # Otherwise we'll want to make the newly visible dock the active tab.
 
@@ -482,7 +496,7 @@ class Window(QtWidgets.QMainWindow):
         # TabBar's are dynamically created as the user
         # moves docks around, and not all of them are
         # visible or in use at all times. (Poor garbage collection)
-        bars = self.findChildren(QtWidgets.QTabBar)
+        bars = self.findChildren(QtWidgets.QTabBar, "")
 
         # The children of a QTabBar isn't the dock directly, but rather
         # the buttons in the tab, which are of type QToolButton.
@@ -581,13 +595,6 @@ class Window(QtWidgets.QMainWindow):
         toggle.setIconSize(QtCore.QSize(width, height))
         toggle.setAutoFillBackground(True)
 
-    def setStyleSheet(self, style):
-        style = style % {
-            "root": os.path.dirname(__file__).replace("\\", "/"),
-            "res": res.dirname.replace("\\", "/"),
-        }
-        super(Window, self).setStyleSheet(style)
-
     def on_repository_changed(self):
         self.reset()
 
